@@ -1,7 +1,7 @@
 #' Dataset to bridge (translate) common sector-classification codes
 #'
 #' @description
-#' These dataset serve as a translation key between common sector-classification
+#' This dataset serves as a translation key between common sector-classification
 #' systems and sectors relevant to the 'PACTA' tool
 #' (<https://2degrees-investing.org/resource/pacta/>).
 #'
@@ -65,3 +65,18 @@
 #' @examples
 #' head(sic_classification)
 "sic_classification"
+
+#' @inherit isic_classification title
+#' @inherit isic_classification description
+#'
+#' @section Definitions:
+#' `r define("gics_classification")`
+#'
+#' @template info_classification-datasets
+#'
+#' @family datasets for bridging sector classification codes
+#' @seealso [data_dictionary].
+#'
+#' @examples
+#' head(gics_classification)
+"gics_classification"
